==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+47"/>
        <source>Status Bar Font:</source>
        <translation>Carattere barra di stato:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation>Widget nella barra di stato</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation>Display di coordinate</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation>Display del mouse</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation>Display della selezione</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation>Display del progresso</translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translation>Barra di stato</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation>Barra di &amp;stato</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/StatusBar/ts/StatusBar_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+53"/>
        <source>Status Bar Font:</source>
        <translation>Carattere barra di stato:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Status Bar Widgets</source>
        <translation>Widget nella barra di stato</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinate display</source>
        <translation>Display di coordinate</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Mouse display</source>
        <translation>Display del mouse</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Selection display</source>
        <translation>Display della selezione</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Progress display</source>
        <translation>Display del progresso</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Show status tips</source>
        <translation>Mostra suggerimenti sullo stato</translation>
    </message>
    <message>
        <location filename="../StatusBar.js" line="+32"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Status Bar</source>
        <translation>Barra di stato</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Status Bar</source>
        <translation>Barra di &amp;stato</translation>
    </message>
</context>
</TS>
